@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.11 2003/12/28 08:06:39 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.12 2004/02/27 10:15:57 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -111,6 +111,23 @@ void do_child(int unix_fd, int inet_fd)
 			continue;
 		}
 
+		/* V3(7.4 or later) protocol? */
+		if ((ntohl(sp->protoVersion)>>16) > 2)
+		{
+			static char *msg = "Sorry, we do not support V3 protocol";
+
+			pool_debug("V3 protocol request received. attempt to fallback to V2");
+
+			/*
+			 * Send "we do not suppport V3 protocol" error in the hope that
+			 * it could fallback to V2 protocol..,.
+			 */
+			pool_write_and_flush(frontend, "E", 1);
+			pool_write_and_flush(frontend, msg, strlen(msg)+1);
+			pool_close(frontend);
+			continue;
+		}
+
 		/* SSL? */
 		if (ntohl(sp->protoVersion) == 0x04D2162F)		/* 0x04D2162F = 12345679 */
 		{
