@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.4 2003/07/05 06:32:33 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.5 2004/02/28 14:06:22 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -158,7 +158,8 @@ int main(int argc, char **argv)
 	mypid = getpid();
 
 	/* set unix domain socket path */
-	snprintf(un_addr.sun_path, sizeof(un_addr.sun_path), "/tmp/.s.PGSQL.%d",
+	snprintf(un_addr.sun_path, sizeof(un_addr.sun_path), "%s/.s.PGSQL.%d",
+			 pool_config.socket_dir,
 			 pool_config.port);
 
 	/* set up signal handlers */
