@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.7 2004/02/27 10:15:57 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.8 2004/02/28 14:06:22 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -68,6 +68,7 @@ typedef enum {
 typedef struct {
     int	inetdomain;	/* should we make an INET domain socket too? */
     int	port;	/* port # to bind */
+	char *socket_dir;		/* pgpool socket directory */
     char	*backend_host_name;	/* backend host name */
     int	backend_port;	/* backend port # */
     char	*secondary_backend_host_name;	/* secondary backend host name */
@@ -77,7 +78,7 @@ typedef struct {
     int	connection_life_time;	/* if idle for this seconds, connection closes */
     int	max_pool;	/* max # of connection pool per child */
     char *logdir;		/* logging directory */
-    char *socket_dir;	/* Unix domain socket directory */
+    char *backend_socket_dir;	/* Unix domain socket directory for the PostgreSQL server */
 
 	/* followings do not exist in the configuration file */
     char	*current_backend_host_name;	/* current backend host name */
