@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.7 2004/02/27 10:15:57 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.8 2004/02/28 14:06:22 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -320,7 +320,9 @@ static  int connect_unix_domain_socket(POOL_CONNECTION_POOL *p)
 
 	memset((char *) &addr, 0, sizeof(addr));
 	((struct sockaddr *)&addr)->sa_family = AF_UNIX;
-	snprintf(addr.sun_path, sizeof(addr.sun_path), "/tmp/.s.PGSQL.%d", pool_config.current_backend_port);
+	snprintf(addr.sun_path, sizeof(addr.sun_path), "%s/.s.PGSQL.%d", 
+			 pool_config.backend_socket_dir,
+			 pool_config.current_backend_port);
 	pool_debug("connecting postmaster Unix domain socket: %s", addr.sun_path);
 
 	len = sizeof(struct sockaddr_un);
