@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.5 2004/01/21 08:19:53 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.6 2004/02/05 14:27:44 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -422,20 +422,31 @@ static POOL_STATUS AsciiRow(POOL_CONNECTION *frontend,
 
 			pool_write(frontend, &size, sizeof(int));
 			size = htonl(size) - 4;
-			buf = malloc(size);
-			if (buf == NULL)
-			{
-				pool_error("AsciiRow: out of memory");
-				return POOL_END;
-			}
-			/* actual data */
-			if (pool_read(backend, buf, size) < 0)
-				return POOL_END;
 
-			pool_write(frontend, buf, size);
-			snprintf(msgbuf, Min(sizeof(msgbuf), size), "%s", buf);
+			/* read and send actual data only when size > 0 */
+			if (size > 0)
+			{
+				buf = malloc(size);
+				if (buf == NULL)
+				{
+					pool_error("AsciiRow: out of memory");
+					return POOL_END;
+				}
+				/* actual data */
+				if (pool_read(backend, buf, size) < 0)
+				{
+					free(buf);
+					return POOL_END;
+				}
+				pool_write(frontend, buf, size);
+				snprintf(msgbuf, Min(sizeof(msgbuf), size), "%s", buf);
+				free(buf);
+			}
+			else
+			{
+				*msgbuf = '\0';
+			}
 			pool_debug("AsciiRow: len:%d data: %s", size, msgbuf);
-			free(buf);
 		}
 		mask >>= 1;
 	}
